##################################### info #################################################
## R Script generates statistical output for the digestive constraint analyses (Figure 3) of crab plovers foraging 
## on different crab species. Case study from Gommer, R et al. (2018). PloS ONE: Stomach fullness shapes prey choice 
## decisions in crab plovers (Dromas ardeola)
# --------------------------------------------------------------------------------------------------------
# Questions can be directed to: Roeland Bom (Roeland.Bom@nioz.nl) and Roy Gommer (roygommer@hotmail.com)
# --------------------------------------------------------------------------------------------------------

# The script runs with 	- R version 3.4.2 (2018-03-16);
# Needed data files:
	# fig3.txt
# --------------------------------------------------------------------------------------------------------

#########################What constrains the intake of crab plovers?####################################


###############################################################################DM (dry mass)
# --------------------------------------------------------------------------------------------------------
data <- read.table('fig3.txt',head=T)
attach(data)
mac <- subset(data, Crab=='Macrophthalmus_sulcatus')
pors <- subset(data, Treatment=='ScS')
porl <- subset(data, Treatment=='ScL')

plot(porl$crabs_s~porl$DM, xlab='DM (g)', ylab='IR (prey/s)', bg='blue', pch=21, 
log='xy',ylim=c(0.0001,0.003),xlim=c(0.17,3), cex=1.5)
points(pors$crabs_s~pors$DM, bg='skyblue3',pch=22, cex=1.5)
points(mac$crabs_s~mac$DM, bg='grey',pch=24, cex=1.5)
legend("topright", c("Macrophthalmus","Portunus (Small)", "Portunus (Large)"), 
cex=1.2, col=c("grey50","cyan2","blue"), pch=c(17,15,16))

abline(lm(log10(data$crabs_s)~log10(data$DM)),lwd=1)

###-0.7473  
m1 <- lme(log10(crabs_s)~log10(DM), random=~1|BirdID)
 summary(m1)
confint(m1, level=0.95)

2*pt(abs(-1- -0.743043)/0.11843896,df=11, lower.tail=F)
###edge of significance, so not likely that intake is contrained by DM
#### p = 0.05282024
# --------------------------------------------------------------------------------------------------------


#############################################################################AFDM (Ash Free Dry Mass)
# --------------------------------------------------------------------------------------------------------
data <- read.table('fig3.txt',head=T)

mac <- subset(data, Crab=='Macrophthalmus_sulcatus')
pors <- subset(data, Treatment=='ScS')
porl <- subset(data, Treatment=='ScL')

plot(porl$crabs_s~porl$AFDM, xlab='AFDM (g)', ylab='IR (prey/s)', col='blue', pch=16, 
log='xy',ylim=c(0.0001,0.003),xlim=c(0.1,2.7), cex=1.5)
points(pors$crabs_s~pors$AFDM, col='skyblue3',pch=15, cex=1.5)
points(mac$crabs_s~mac$AFDM, col='grey50',pch=17, cex=1.5)
legend("topright", c("Macrophthalmus","Portunus (Small)", "Portunus (Large)"), cex=1.5, 
col=c("grey","skyblue3","blue"), pch=c(24,22,21))

abline(lm(log10(data$crabs_s)~log10(data$AFDM)),lwd=1)
###-0.6397 

m2 <- lm(log10(data$crabs_s)~log10(data$AFDM))
summary(m2)
confint(m2, level=0.95)

2*pt(abs(-1--0.63970)/ 0.10211,df=13, lower.tail=F)
#### p = 0.003705614 : does differ from -1
####so intake is not constrained by AFDM
# --------------------------------------------------------------------------------------------------------



##############################################################################Ash
# --------------------------------------------------------------------------------------------------------
data <- read.table('fig3.txt',head=T)

data$ash_mg <- data$Ash*1000
attach(data)
mac <- subset(data, Crab=='Macrophthalmus_sulcatus')
pors <- subset(data, Treatment=='ScS')
porl <- subset(data, Treatment=='ScL')

############################################################### Log Axis
plot(porl$crabs_s~porl$Ash, xlab='Ash (g)', ylab='IR (prey/s)', bg='royalblue1', pch=21, 
log='xy',ylim=c(0.0001,0.003),xlim=c(0.09,1.2), cex=1.7)
points(pors$crabs_s~pors$Ash, bg='royalblue1',pch=22, cex=1.7)
points(mac$crabs_s~mac$Ash, bg='grey',pch=24, cex=1.7)
legend("topright", expression(italic("Macrophthalmus"),paste("small ", italic("Portunus")), paste("large ", 
italic("Portunus"))), pt.cex=1.7, cex=1.1, pt.bg=c("grey","royalblue1","royalblue1"), pch=c(24,22,21))

##abline(lm(log10(data$crabs_s)~log10(data$Ash)),lwd=1)
library(nlme)
m3 <- lme(log10(crabs_s)~log10(Ash), random=~1|BirdID)
summary(m3)

confint(m3, level=0.95)
2*pt(abs(-1--0.936648)/0.1841176,df=11, lower.tail=F)

#### p = 0.7372704
###########So no significant difference from -1, INTAKE CONTRAINED BY ASH

###line of model
###abline(a = -3.796315 , b = -0.936648, lwd = 1.5, col = 'black')

###Line with slope= -1
abline(a = -3.796315 , b = -1, lwd = 2, col = 'black',lty=1)

####VALUE OF CONSTRAINT
#abline(h=(10^-3.796315),lty=2, lwd=2)
10^-3.796315

#############constraint
###0.0001598398 
### 0.16 mg/s
# --------------------------------------------------------------------------------------------------------



