##################################### info #################################################
## R Script generates output of dicotomous prey choice experiment (Figure 5) of crab plovers foraging 
## on different crab species. Case study from Gommer, R et al. (2018). PloS ONE: Stomach fullness 
## shapes prey choice decisions in crab plovers (Dromas ardeola)

# --------------------------------------------------------------------------------------------------------
# Questions can be directed to: Roeland Bom (Roeland.Bom@nioz.nl) and Roy Gommer (roygommer@hotmail.com)
# --------------------------------------------------------------------------------------------------------

# The script runs with 	- R version 3.4.2 (2018-03-16);
# Needed data files:
	# fig5.txt
# --------------------------------------------------------------------------------------------------------


###Dicotomous prey choice experiment
# --------------------------------------------------------------------------------------------------------

### read data
data <- read.table('fig5.txt', head= T) 

###loading packages
library(nlme)
library(lme4)

###Comparing scl (Large Portunus) with the others: scs (Small Portunus) and bc (Macrophthalmus)
m1 <- glm(choice~-1+bc+scs+scl, data = data, family = quasibinomial(link='logit'))
summary(m1)

###parameter from the model to use in plot
est <- c(1.9303, 1.6724 , 0)
SE <- c(0.5547, 0.5334, 0)
species1 <- c(1,2,3)
species <- c('Macropthalmus', 'small Portunus', 'large Portunus')

###making plot
x <- 0
y <- 0

plot(x~y,  ylim=c(-0.5,2.5), xlim= c(0.75,3.25),bg=c('grey', 'royalblue1', 'royalblue1'), 
pch=c(24,22,21), cex=0, axes = FALSE, ann = FALSE)
box()

arrows(species1, est, x1 = species1, y1 = est-SE, length = 0.05, angle = 90, code = 2)
arrows(species1, est, x1 = species1, y1 = est+SE, length = 0.05, angle = 90, code = 2)

points(est~species1, ylab='Cardinal preference rank', ylim=c(-0.5,2.5), bg=c('grey', 'royalblue1', 'royalblue1'), 
pch=c(24,22,21), cex=2.5)
axis(2)
axis(1,at = c(1,2,3), labels=F)
mtext(expression(italic('Macrophthalmus')), 3, adj=-0.04, padj=25.2)
mtext(expression(paste('small ',italic('Portunus'))), 3, adj=0.5, padj=31.45)
mtext(expression(paste('large ',italic('Portunus'))), 3, adj=1, padj=25)

title(ylab='Cardinal preference rank')
# --------------------------------------------------------------------------------------------------------





