##################################### info #################################################
## R Script generates output of cafetaria experiment (Figure 6) of crab plovers foraging 
## on different crab species. Case study from Gommer, R et al. (2018). PloS ONE: Stomach fullness 
## shapes prey choice decisions in crab plovers (Dromas ardeola)

# --------------------------------------------------------------------------------------------------------
# Questions can be directed to: Roeland Bom (Roeland.Bom@nioz.nl) and Roy Gommer (roygommer@hotmail.com)
# --------------------------------------------------------------------------------------------------------

# The script runs with 	- R version 3.4.2 (2018-03-16);
# Needed data files:
	# fig6_24nov_G2WRRG.txt
	# fig6_22nov_G2WRRG.txt
	# fig6_21nov_G2WRRN.txt
	# fig6_23nov_G2WRRN.txt
# --------------------------------------------------------------------------------------------------------



###CAFETARIA EXPERIMENT
# --------------------------------------------------------------------------------------------------------

###opening window for multiple plotting
par(mar=c(0.5, 0.5, 0.5, 0.5), mfcol=c(1,2),oma = c(3.5, 3.5, 1, 1))


###G2WRRG_24nov
# --------------------------------------------------------------------------------------------------------
data <- read.table('fig6_24nov_G2WRRG.txt', head=T)

###Time correction for the start of the experiment########
data$correct_time <- (data$Timecorrect-data$Timecorrect[2]) 

data2 <- data[which(data$State_event=='Swallow_flesh'|data$State_event=='Swallow_whole'),]
data2$crab <- 1
data2$crab_cum <- cumsum(data2$crab)
data2$time_min <- data2$correct_time/60
plot(data2$crab_cum~data2$time_min, ylab='IR (#prey)', xlab='time (min)', bg=c("grey","royalblue1","royalblue1")[data2$Mod], 
xlim=c(0,120), ylim=c(0,23), pch=c(24, 21, 22)[data2$Mod],  cex=2, type='o')

###no camera failure
# --------------------------------------------------------------------------------------------------------


###G2WRRG_22nov
# --------------------------------------------------------------------------------------------------------
###Deleted since crab plover had eaten all macropthalmus before end of experiment

###data <- read.table('fig6_22nov_G2WRRG.txt', head=T)
####Time correction for the start of the experiment########
###data$correct_time <- (data$Timecorrect-data$Timecorrect[2]) 

###data2 <- data[which(data$State_event=='Swallow_flesh'|data$State_event=='Swallow_whole'),]
###data2$crab <- 1
###data2$crab_cum <- cumsum(data2$crab)
###data2$time_min <- data2$correct_time/60
###plot(data2$crab_cum~data2$time_min, ylab='IR (#prey)', xlab='time (min)', bg=c("grey","royalblue1")[data2$Mod], 
###xlim=c(0,120), ylim=c(0,23), pch=c(24, 22)[data2$Mod], cex=2, type='o')
###abline(v=17.4)
###segments(17.5, 16, x1 = 100, y1 = 20,col='black', lty=2)

###in_out <- read.table('fig6_In_out_experiment.txt', head=T)
###eaten after camera failure: 
###Macrophthalmus: 0
###Portunus small: 4

###interval for plotting
###(100-14.77)/4

###x and y values
###x <- c((14.77+21.3075), (14.77+21.3075*2),(14.77+21.3075*3),(14.77+21.3075*4))
###y <- c(17, 18, 19, 20)

###adding points to the plot in regular intervals and random order
###points(y~x, bg=c("royalblue1","royalblue1","royalblue1","royalblue1"), pch=c(22,22,22,22), cex=2)
# --------------------------------------------------------------------------------------------------------


###G2WRRN_21nov
# --------------------------------------------------------------------------------------------------------
data <- read.table('fig6_21nov_G2WRRN.txt', head=T)
####Time correction for the start of the experiment########
data$correct_time <- (data$Timecorrect-data$Timecorrect[2]) 

data2 <- data[which(data$State_event=='Swallow_flesh'|data$State_event=='Swallow_whole'),]
data2$crab <- 1
data2$crab_cum <- cumsum(data2$crab)
data2$time_min <- data2$correct_time/60

plot(data2$crab_cum~data2$time_min, ylab='IR (#prey)', xlab='time (min)', xlim=c(0,120), ylim=c(0,23), 
bg=c("grey","royalblue1")[data2$Mod], pch=c(24,22)[data2$Mod], cex=2, type='o',ann=FALSE,yaxt="n")
 
axis(side=2,labels=F) 
abline(v=9.8)
segments(10, 10, x1 = 100, y1 = 16,col='black', lty=2)

in_out <- read.table('fig6_In_out_experiment.txt', head=T)
###eaten after camera failure: 
###Macrophthalmus: 1
###Portunus small: 5

###interval for plotting
(100-7.63)/6

###x and y values
x <- c((7.63+15.395), (7.63+15.395*2),(7.63+15.395*3),(7.63+15.395*4),(7.63+15.395*5),(7.63+15.395*6))
y <- c(11, 12, 13, 14, 15, 16)

###adding points to the plot in regular intervals and random order
points(y~x, bg=c("royalblue1","royalblue1","royalblue1","grey","royalblue1","royalblue1"), 
pch=c(22,22,22,24,22,22), cex=2)
# --------------------------------------------------------------------------------------------------------


###G2WRRN_23nov
# --------------------------------------------------------------------------------------------------------
###Deleted since crab plover had eaten all macropthalmus before end of experiment

###data <- read.table('fig6_23nov_G2WRRN.txt', head=T)
####Time correction for the start of the experiment########
###data$correct_time <- (data$Timecorrect-data$Timecorrect[2]) 

###data2 <- data[which(data$State_event=='Swallow_flesh'|data$State_event=='Swallow_whole'),]
###data2$crab <- 1
###data2$crab_cum <- cumsum(data2$crab)
###data2$time_min <- data2$correct_time/60
###plot(data2$crab_cum~data2$time_min, ylab='IR (#prey)', xlab='time (min)', bg=c("grey","royalblue1")[data2$Mod], 
###xlim=c(0,120), ylim=c(0,23), pch=c(24, 22)[data2$Mod],  cex=2, type='o',ann=FALSE,yaxt="n")
###axis(side=2,labels=F) 
###abline(v=11.5)
###segments(12, 16, x1 = 100, y1 = 16,col='black', lty=2)

###in_out <- read.table('fig6_In_out_experiment.txt', head=T)
###stopped eating after camera failure!!! 

###adding legend to the graph
legend("bottomright", expression(italic("Macrophthalmus"),  paste("small ",italic("Portunus")), paste("large ",italic("Portunus"), 
)), cex=1, pt.bg=c("grey","royalblue1","royalblue1"), pch=c(24, 22, 21), pt.cex=2)

###adding text to the axis
mtext("Cumulative intake (# prey)", 2,cex=1.1, adj=0.43, padj=-26.5)
mtext("Time (min)", 1, adj=-0.24, padj=3.5)

###mtext("trial 1", 3, adj=-0.765, padj=-22)
###mtext("trial 2", 3, adj=0.51, padj=-22)

mtext("trial 1", 3,  adj=-0.74, padj=1.65)
mtext("trial 2", 3,  adj=0.50, padj=1.65)
# --------------------------------------------------------------------------------------------------------



